@@ -15,6 +15,8 @@
 from oslo_config import cfg
 
 
+_DEFAULT_BACKEND = 'dogpile.cache.null'
+
 FILE_OPTIONS = {
     'cache': [
         cfg.StrOpt('config_prefix', default='cache.oslo',
@@ -35,7 +37,7 @@ FILE_OPTIONS = {
         # prevent issues with the memory cache ending up in "production"
         # unintentionally, we register a no-op as the keystone default caching
         # backend.
-        cfg.StrOpt('backend', default='dogpile.cache.null',
+        cfg.StrOpt('backend', default=_DEFAULT_BACKEND,
                    help='Dogpile.cache backend module. It is recommended '
                         'that Memcache with pooling '
                         '(oslo_cache.memcache_pool) or Redis '
